import { ServiceConfig as ServiceConfig$1, AuthenticationService as AuthenticationService$1 } from '@cleavelandprice/ngx-lib/authentication/token';
import * as i0 from '@angular/core';
import { inject, Injectable, Optional, Component, input, NgModule, SkipSelf } from '@angular/core';
import { JwtHelperService } from '@auth0/angular-jwt';
import { SharePointService } from '@cleavelandprice/ngx-lib/sharepoint';
import * as i3 from '@angular/material/dialog';
import { MAT_DIALOG_DATA, MatDialogRef, MatDialog, MatDialogModule } from '@angular/material/dialog';
import { ConfirmationComponent } from '@cleavelandprice/ngx-lib/dialog';
import * as i1 from '@angular/forms';
import { FormGroup, FormControl, Validators, ReactiveFormsModule } from '@angular/forms';
import * as i2 from '@angular/material/button';
import { MatButtonModule } from '@angular/material/button';
import * as i4 from '@angular/material/form-field';
import { MatFormFieldModule } from '@angular/material/form-field';
import * as i5 from '@angular/material/icon';
import { MatIconModule } from '@angular/material/icon';
import * as i6 from '@angular/material/input';
import { MatInputModule } from '@angular/material/input';
import * as i7 from '@angular/material/progress-spinner';
import { MatProgressSpinnerModule } from '@angular/material/progress-spinner';
import * as i8 from '@angular/material/slide-toggle';
import { MatSlideToggleModule } from '@angular/material/slide-toggle';
import { CommonModule } from '@angular/common';

//import { ServiceConfig as NgxLibServiceConfig } from '@cleavelandprice/ngx-lib';
class ServiceConfig extends ServiceConfig$1 {
    // See the comment in the library's main service-config.ts file for an explanation
    constructor(useSsl_or_customApiUrl = false, showRememberMeOption = true, appName, tokenName = 'token', authenticateEndpoint = '/authenticate/token') {
        super(useSsl_or_customApiUrl, appName, tokenName, authenticateEndpoint);
        this.showRememberMeOption = showRememberMeOption;
    }
}

class AuthenticationService extends AuthenticationService$1 {
    //#endregion
    //#region Lifecycle
    constructor(config) {
        config = config ?? new ServiceConfig();
        /*config = {
          ...new ServiceConfig(),
          ...config,

          // Need to force deferTokenValidation here because if a custom config was passed in, deferTokenValidation would have defaulted to false since it's the default boolean value
          // If a custom config wasn't passed in, then deferTokenValidation would have been true from defaultConfig
          deferTokenValidation: true
        };*/
        // Need to force deferTokenValidation here because if a custom config was passed in, deferTokenValidation would have defaulted to false since it's the default boolean value
        // If a custom config wasn't passed in, then deferTokenValidation would have been true from defaultConfig
        config.deferTokenValidation = true;
        super(config);
        this.config = config;
        //#region Services
        this.sharePointService = inject(SharePointService);
        this.checkForExistingToken();
    }
    //#endregion
    //#region Utilities
    validateUser(token) {
        const jwtHelper = new JwtHelperService();
        const decoded = jwtHelper.decodeToken(token);
        if (jwtHelper.isTokenExpired(token)) {
            this.logout();
            return;
        }
        this.authenticatedUser = {
            admin: decoded.role === 'Admin',
            displayName: decoded.displayName,
            accountName: decoded.winaccountname,
            distinguishedName: decoded.distinguishedName,
            employeeNumber: decoded.employeeNumber,
            memberOf: decoded.memberOf
        };
        this.storage.setItem(this.config.tokenName, token);
        this.getPhoto();
        this.authenticated = true;
        this.authenticatedChanged.emit(this.authenticated);
        this.authenticating = false;
        this.authenticatingChanged.emit(this.authenticating);
    }
    getPhoto() {
        this.sharePointService.getPhotos()
            .subscribe(photos => {
            // The user may have been logged out by the time the photos came back
            if (!this.authenticatedUser?.employeeNumber) {
                return;
            }
            const photo = photos.find(pic => pic.employeeNumber === +this.authenticatedUser.employeeNumber);
            if (photo) {
                this.authenticatedUser.photoUrl = photo.encodedAbsUrl;
            }
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: AuthenticationService, deps: [{ token: ServiceConfig, optional: true }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: AuthenticationService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: AuthenticationService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [{ type: ServiceConfig, decorators: [{
                    type: Optional
                }] }] });

class LoginFormComponent {
    constructor() {
        this.#data = inject(MAT_DIALOG_DATA);
        //#region Services
        this.dialogRef = inject((MatDialogRef));
        this.authenticationService = inject(AuthenticationService);
        this.form = new FormGroup({
            username: new FormControl(null, [Validators.required]),
            password: new FormControl(null, [Validators.required]),
            adminGroup: new FormControl(),
            additionalInfo: new FormControl()
        });
    }
    #data;
    ngOnInit() {
        this.form.get('adminGroup')?.setValue(this.#data.adminGroup);
        this.form.get('additionalInfo')?.setValue(this.#data.additionalInfo);
        this.authenticatedChangedSubscription = this.authenticationService.authenticatedChanged
            .subscribe(this.authChangedHandler.bind(this));
        this.authenticationErrorSubscription = this.authenticationService.authenticationError
            .subscribe(this.errorHandler.bind(this));
    }
    ngOnDestroy() {
        this.authenticationErrorSubscription.unsubscribe();
        this.authenticatedChangedSubscription.unsubscribe();
    }
    authenticate() {
        this.errorMessage = undefined;
        const { username, password, adminGroup, additionalInfo } = this.form.value;
        this.authenticationService.login(username, password, adminGroup, additionalInfo);
    }
    authChangedHandler(authenticated) {
        if (authenticated) {
            this.dialogRef.close();
        }
    }
    errorHandler(err) {
        console.log('Authentication error', err);
        this.errorMessage = `${err.name}: ${err.statusText}`;
    }
    changeTokenStorageMode(checked) {
        const keyName = 'storeTokenInSession';
        if (checked) {
            if (localStorage.getItem(keyName)) {
                localStorage.removeItem(keyName);
            }
        }
        else {
            localStorage.setItem(keyName, 'true');
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: LoginFormComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "17.3.0", type: LoginFormComponent, selector: "ng-component", ngImport: i0, template: "<h2 mat-dialog-title>\r\n  @if (authenticationService.authenticating) {\r\n    <span>Authenticating...</span>\r\n  } @else {\r\n    <span>Login</span>\r\n  }\r\n</h2>\r\n\r\n<mat-dialog-content>\r\n  @if (authenticationService.authenticating) {\r\n    <div id=\"spinner\">\r\n      <mat-progress-spinner color=\"primary\" mode=\"indeterminate\"/>\r\n    </div>\r\n  } @else if (errorMessage) {\r\n    <div id=\"error\">\r\n      {{ errorMessage }}\r\n    </div>\r\n  } @else {\r\n    <form [formGroup]=\"form\">\r\n      <mat-form-field>\r\n        <input matInput formControlName=\"username\" placeholder=\"Username\" (keyup.enter)=\"authenticate()\">\r\n      </mat-form-field>\r\n      <mat-form-field>\r\n        <input matInput formControlName=\"password\" type=\"password\" placeholder=\"Password\" (keyup.enter)=\"authenticate()\">\r\n      </mat-form-field>\r\n      @if (authenticationService.config.showRememberMeOption) {\r\n        <mat-slide-toggle [checked]=\"!authenticationService.useSessionStorage\" (change)=\"changeTokenStorageMode($event.checked)\">\r\n          Remember me next time\r\n        </mat-slide-toggle>\r\n      }\r\n    </form>\r\n  }\r\n</mat-dialog-content>\r\n\r\n@if (!authenticationService.authenticating) {\r\n  <mat-dialog-actions>\r\n    <button mat-raised-button color=\"primary\" (click)=\"authenticate()\"\r\n      [disabled]=\"form.invalid\">\r\n      <mat-icon fontIcon=\"done\"/>\r\n      <span>OK</span>\r\n    </button>\r\n    <button mat-raised-button (click)=\"dialogRef.close()\">\r\n      <mat-icon fontIcon=\"close\"/>\r\n      <span>Cancel</span>\r\n    </button>\r\n  </mat-dialog-actions>\r\n}", styles: ["#spinner{width:100%;height:100%;display:flex;justify-content:center;align-items:center}form{display:grid;gap:1rem}mat-dialog-actions{display:grid;justify-content:center;grid-template-columns:auto auto;gap:1rem}#error{color:red}\n", ".material-icons{font-family:Material Icons;font-weight:400;font-style:normal;font-size:24px;display:inline-block;line-height:1;text-transform:none;letter-spacing:normal;word-wrap:normal;white-space:nowrap;direction:ltr;-webkit-font-smoothing:antialiased;text-rendering:optimizeLegibility;-moz-osx-font-smoothing:grayscale;font-feature-settings:\"liga\"}\n"], dependencies: [{ kind: "directive", type: i1.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i1.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "directive", type: i1.FormControlName, selector: "[formControlName]", inputs: ["formControlName", "disabled", "ngModel"], outputs: ["ngModelChange"] }, { kind: "component", type: i2.MatButton, selector: "    button[mat-button], button[mat-raised-button], button[mat-flat-button],    button[mat-stroked-button]  ", exportAs: ["matButton"] }, { kind: "directive", type: i3.MatDialogTitle, selector: "[mat-dialog-title], [matDialogTitle]", inputs: ["id"], exportAs: ["matDialogTitle"] }, { kind: "directive", type: i3.MatDialogActions, selector: "[mat-dialog-actions], mat-dialog-actions, [matDialogActions]", inputs: ["align"] }, { kind: "directive", type: i3.MatDialogContent, selector: "[mat-dialog-content], mat-dialog-content, [matDialogContent]" }, { kind: "component", type: i4.MatFormField, selector: "mat-form-field", inputs: ["hideRequiredMarker", "color", "floatLabel", "appearance", "subscriptSizing", "hintLabel"], exportAs: ["matFormField"] }, { kind: "component", type: i5.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { kind: "directive", type: i6.MatInput, selector: "input[matInput], textarea[matInput], select[matNativeControl],      input[matNativeControl], textarea[matNativeControl]", inputs: ["disabled", "id", "placeholder", "name", "required", "type", "errorStateMatcher", "aria-describedby", "value", "readonly"], exportAs: ["matInput"] }, { kind: "component", type: i7.MatProgressSpinner, selector: "mat-progress-spinner, mat-spinner", inputs: ["color", "mode", "value", "diameter", "strokeWidth"], exportAs: ["matProgressSpinner"] }, { kind: "component", type: i8.MatSlideToggle, selector: "mat-slide-toggle", inputs: ["name", "id", "labelPosition", "aria-label", "aria-labelledby", "aria-describedby", "required", "color", "disabled", "disableRipple", "tabIndex", "checked", "hideIcon"], outputs: ["change", "toggleChange"], exportAs: ["matSlideToggle"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: LoginFormComponent, decorators: [{
            type: Component,
            args: [{ template: "<h2 mat-dialog-title>\r\n  @if (authenticationService.authenticating) {\r\n    <span>Authenticating...</span>\r\n  } @else {\r\n    <span>Login</span>\r\n  }\r\n</h2>\r\n\r\n<mat-dialog-content>\r\n  @if (authenticationService.authenticating) {\r\n    <div id=\"spinner\">\r\n      <mat-progress-spinner color=\"primary\" mode=\"indeterminate\"/>\r\n    </div>\r\n  } @else if (errorMessage) {\r\n    <div id=\"error\">\r\n      {{ errorMessage }}\r\n    </div>\r\n  } @else {\r\n    <form [formGroup]=\"form\">\r\n      <mat-form-field>\r\n        <input matInput formControlName=\"username\" placeholder=\"Username\" (keyup.enter)=\"authenticate()\">\r\n      </mat-form-field>\r\n      <mat-form-field>\r\n        <input matInput formControlName=\"password\" type=\"password\" placeholder=\"Password\" (keyup.enter)=\"authenticate()\">\r\n      </mat-form-field>\r\n      @if (authenticationService.config.showRememberMeOption) {\r\n        <mat-slide-toggle [checked]=\"!authenticationService.useSessionStorage\" (change)=\"changeTokenStorageMode($event.checked)\">\r\n          Remember me next time\r\n        </mat-slide-toggle>\r\n      }\r\n    </form>\r\n  }\r\n</mat-dialog-content>\r\n\r\n@if (!authenticationService.authenticating) {\r\n  <mat-dialog-actions>\r\n    <button mat-raised-button color=\"primary\" (click)=\"authenticate()\"\r\n      [disabled]=\"form.invalid\">\r\n      <mat-icon fontIcon=\"done\"/>\r\n      <span>OK</span>\r\n    </button>\r\n    <button mat-raised-button (click)=\"dialogRef.close()\">\r\n      <mat-icon fontIcon=\"close\"/>\r\n      <span>Cancel</span>\r\n    </button>\r\n  </mat-dialog-actions>\r\n}", styles: ["#spinner{width:100%;height:100%;display:flex;justify-content:center;align-items:center}form{display:grid;gap:1rem}mat-dialog-actions{display:grid;justify-content:center;grid-template-columns:auto auto;gap:1rem}#error{color:red}\n", ".material-icons{font-family:Material Icons;font-weight:400;font-style:normal;font-size:24px;display:inline-block;line-height:1;text-transform:none;letter-spacing:normal;word-wrap:normal;white-space:nowrap;direction:ltr;-webkit-font-smoothing:antialiased;text-rendering:optimizeLegibility;-moz-osx-font-smoothing:grayscale;font-feature-settings:\"liga\"}\n"] }]
        }] });

class LoginComponent {
    constructor() {
        //#region Services
        this.dialog = inject(MatDialog);
        this.authenticationService = inject(AuthenticationService);
        //#endregion
        this.adminGroup = input();
        this.additionalInfo = input.required();
    }
    login() {
        this.dialog.open(LoginFormComponent, {
            data: {
                adminGroup: this.adminGroup(),
                additionalInfo: this.additionalInfo()
            }
        });
    }
    confirmLogout() {
        this.dialog.open(ConfirmationComponent, {
            data: { message: `Are you sure you want to logout?` }
        })
            .afterClosed()
            .subscribe(result => {
            if (result) {
                this.authenticationService.logout();
            }
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: LoginComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "17.3.0", type: LoginComponent, selector: "cp-login", inputs: { adminGroup: { classPropertyName: "adminGroup", publicName: "adminGroup", isSignal: true, isRequired: false, transformFunction: null }, additionalInfo: { classPropertyName: "additionalInfo", publicName: "additionalInfo", isSignal: true, isRequired: true, transformFunction: null } }, ngImport: i0, template: "<div id=\"user-id\">\r\n  <!-- Logged out -->\r\n  <!-- Logged in -->\r\n  @if (authenticationService.authenticated) {\r\n    <!-- With photo -->\r\n    @if (authenticationService.authenticatedUser?.photoUrl) {\r\n      <img\r\n        id=\"authenticated-user-image\"\r\n        [src]=\"authenticationService.authenticatedUser?.photoUrl\"\r\n        matTooltip=\"Logout\"\r\n        (click)=\"confirmLogout()\" />\r\n    } @else {\r\n      <!-- Without photo -->\r\n      <mat-icon\r\n        fontIcon=\"account_circle\"\r\n        matTooltip=\"Logout\"\r\n        (click)=\"confirmLogout()\">\r\n      </mat-icon>\r\n    }\r\n    <!-- Name -->\r\n    <div id=\"user-name\">\r\n      {{ authenticationService.authenticatedUser?.displayName }}\r\n    </div>\r\n  } @else {\r\n    <mat-icon\r\n      fontIcon=\"account_circle\"\r\n      matTooltip=\"Login\"\r\n      (click)=\"login()\">\r\n    </mat-icon>\r\n  }\r\n</div>", styles: ["#user-id{display:flex;height:2em;padding:.3em;font-family:Verdana,Geneva,Tahoma,sans-serif}mat-icon{font-size:2em!important;height:2em!important;width:2em!important}img{border-radius:100%;width:2em;height:2em}#user-id>div{display:flex;align-items:center;height:100%;margin-left:.75em;font-size:1.15em}\n", ".material-icons{font-family:Material Icons;font-weight:400;font-style:normal;font-size:24px;display:inline-block;line-height:1;text-transform:none;letter-spacing:normal;word-wrap:normal;white-space:nowrap;direction:ltr;-webkit-font-smoothing:antialiased;text-rendering:optimizeLegibility;-moz-osx-font-smoothing:grayscale;font-feature-settings:\"liga\"}\n"], dependencies: [{ kind: "component", type: i5.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: LoginComponent, decorators: [{
            type: Component,
            args: [{ selector: 'cp-login', template: "<div id=\"user-id\">\r\n  <!-- Logged out -->\r\n  <!-- Logged in -->\r\n  @if (authenticationService.authenticated) {\r\n    <!-- With photo -->\r\n    @if (authenticationService.authenticatedUser?.photoUrl) {\r\n      <img\r\n        id=\"authenticated-user-image\"\r\n        [src]=\"authenticationService.authenticatedUser?.photoUrl\"\r\n        matTooltip=\"Logout\"\r\n        (click)=\"confirmLogout()\" />\r\n    } @else {\r\n      <!-- Without photo -->\r\n      <mat-icon\r\n        fontIcon=\"account_circle\"\r\n        matTooltip=\"Logout\"\r\n        (click)=\"confirmLogout()\">\r\n      </mat-icon>\r\n    }\r\n    <!-- Name -->\r\n    <div id=\"user-name\">\r\n      {{ authenticationService.authenticatedUser?.displayName }}\r\n    </div>\r\n  } @else {\r\n    <mat-icon\r\n      fontIcon=\"account_circle\"\r\n      matTooltip=\"Login\"\r\n      (click)=\"login()\">\r\n    </mat-icon>\r\n  }\r\n</div>", styles: ["#user-id{display:flex;height:2em;padding:.3em;font-family:Verdana,Geneva,Tahoma,sans-serif}mat-icon{font-size:2em!important;height:2em!important;width:2em!important}img{border-radius:100%;width:2em;height:2em}#user-id>div{display:flex;align-items:center;height:100%;margin-left:.75em;font-size:1.15em}\n", ".material-icons{font-family:Material Icons;font-weight:400;font-style:normal;font-size:24px;display:inline-block;line-height:1;text-transform:none;letter-spacing:normal;word-wrap:normal;white-space:nowrap;direction:ltr;-webkit-font-smoothing:antialiased;text-rendering:optimizeLegibility;-moz-osx-font-smoothing:grayscale;font-feature-settings:\"liga\"}\n"] }]
        }] });

class GuiModule {
    static forRoot(config) {
        return {
            ngModule: GuiModule,
            providers: [
                AuthenticationService,
                { provide: ServiceConfig, useValue: config }
            ]
        };
    }
    constructor(parentModule) {
        if (parentModule) {
            throw new Error('GuiModule is already loaded. Import it in the AppModule only');
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: GuiModule, deps: [{ token: GuiModule, optional: true, skipSelf: true }], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.3.0", ngImport: i0, type: GuiModule, declarations: [LoginComponent,
            LoginFormComponent], imports: [CommonModule,
            ReactiveFormsModule,
            MatButtonModule,
            MatDialogModule,
            MatFormFieldModule,
            MatIconModule,
            MatInputModule,
            MatProgressSpinnerModule,
            MatSlideToggleModule], exports: [LoginComponent,
            LoginFormComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: GuiModule, imports: [CommonModule,
            ReactiveFormsModule,
            MatButtonModule,
            MatDialogModule,
            MatFormFieldModule,
            MatIconModule,
            MatInputModule,
            MatProgressSpinnerModule,
            MatSlideToggleModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: GuiModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        LoginComponent,
                        LoginFormComponent
                    ],
                    imports: [
                        CommonModule,
                        ReactiveFormsModule,
                        MatButtonModule,
                        MatDialogModule,
                        MatFormFieldModule,
                        MatIconModule,
                        MatInputModule,
                        MatProgressSpinnerModule,
                        MatSlideToggleModule
                    ],
                    exports: [
                        LoginComponent,
                        LoginFormComponent
                    ]
                }]
        }], ctorParameters: () => [{ type: GuiModule, decorators: [{
                    type: Optional
                }, {
                    type: SkipSelf
                }] }] });

/**
 * Generated bundle index. Do not edit.
 */

export { AuthenticationService, GuiModule, LoginComponent, LoginFormComponent, ServiceConfig };
//# sourceMappingURL=cleavelandprice-ngx-lib-authentication-token-gui.mjs.map
