import * as i0 from '@angular/core';
import { input, EventEmitter, Component, Output, inject, NgModule } from '@angular/core';
import * as i1 from '@angular/forms';
import { FormsModule } from '@angular/forms';
import * as i2 from '@angular/material/button';
import { MatButtonModule } from '@angular/material/button';
import * as i3 from '@angular/material/checkbox';
import { MatCheckboxModule } from '@angular/material/checkbox';
import * as i4 from '@angular/material/dialog';
import { MAT_DIALOG_DATA, MatDialogRef, MatDialogModule } from '@angular/material/dialog';
import * as i5 from '@angular/material/form-field';
import { MatFormFieldModule } from '@angular/material/form-field';
import * as i6 from '@angular/material/input';
import { MatInputModule } from '@angular/material/input';
import { CommonModule } from '@angular/common';

var ConfirmationDialogMode;
(function (ConfirmationDialogMode) {
    ConfirmationDialogMode[ConfirmationDialogMode["OkCancel"] = 0] = "OkCancel";
    ConfirmationDialogMode[ConfirmationDialogMode["YesNo"] = 1] = "YesNo";
    ConfirmationDialogMode[ConfirmationDialogMode["TrueFalse"] = 2] = "TrueFalse";
    ConfirmationDialogMode[ConfirmationDialogMode["Custom"] = 3] = "Custom";
})(ConfirmationDialogMode || (ConfirmationDialogMode = {}));

var DialogType;
(function (DialogType) {
    DialogType[DialogType["Choice"] = 0] = "Choice";
    DialogType[DialogType["Confirmation"] = 1] = "Confirmation";
    DialogType[DialogType["Input"] = 2] = "Input";
    DialogType[DialogType["Message"] = 3] = "Message";
})(DialogType || (DialogType = {}));

class BaseComponent {
    constructor() {
        // This is so that DialogType can be accessible from the HTML template
        this.DialogType = DialogType;
        this.dialogType = input(DialogType.Message);
        this.data = input.required();
        this.closed = new EventEmitter();
        this.ConfirmationDialogMode = ConfirmationDialogMode;
    }
    get #customTrueFalseTextValid() {
        return this.data().customTrueFalseText?.length === 2;
    }
    get customTrueText() {
        return this.#customTrueFalseTextValid ?
            this.data().customTrueFalseText[0] :
            undefined;
    }
    get customFalseText() {
        return this.#customTrueFalseTextValid ?
            this.data().customTrueFalseText[1] :
            undefined;
    }
    get choices() {
        return this.dialogType() === DialogType.Choice ?
            this.data().choices :
            null;
    }
    ngOnInit() {
        this.userInput = this.data().value;
    }
    close() {
        let data;
        switch (this.dialogType()) {
            case DialogType.Message:
                data = this.data().checkboxMessage ?
                    {
                        checkbox: this.checkboxValue || false
                    } :
                    null;
                break;
            case DialogType.Input:
                data = this.data().checkboxMessage ?
                    {
                        response: this.userInput,
                        checkbox: this.checkboxValue || false
                    } :
                    this.userInput;
                break;
            case DialogType.Confirmation:
                data = this.data().checkboxMessage ?
                    {
                        response: true,
                        checkbox: this.checkboxValue || false
                    } :
                    true;
                break;
        }
        this.closed.emit(data);
    }
    cancel() {
        let data;
        if (this.dialogType() === DialogType.Confirmation) {
            data = this.data().checkboxMessage ?
                {
                    response: false,
                    checkbox: this.checkboxValue || false
                } :
                false;
        }
        this.closed.emit(data);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: BaseComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "17.3.0", type: BaseComponent, selector: "cp-dialog-base", inputs: { dialogType: { classPropertyName: "dialogType", publicName: "dialogType", isSignal: true, isRequired: false, transformFunction: null }, data: { classPropertyName: "data", publicName: "data", isSignal: true, isRequired: true, transformFunction: null } }, outputs: { closed: "closed" }, ngImport: i0, template: "@if (data().title) {\r\n  <h2 mat-dialog-title [innerHTML]=\"data().title\"></h2>\r\n}\r\n\r\n<mat-dialog-content>\r\n  @if (data().message) {\r\n    <div [innerHTML]=\"data().message\"></div>\r\n  }\r\n\r\n  @if (dialogType() === DialogType.Input) {\r\n    <mat-form-field>\r\n      <textarea matInput [placeholder]=\"data().placeholder ?? ''\" [(ngModel)]=\"userInput\"></textarea>\r\n    </mat-form-field>\r\n  }\r\n\r\n  @if (data().checkboxMessage) {\r\n    <div id=\"checkbox\">\r\n      <mat-checkbox [(ngModel)]=\"checkboxValue\">\r\n        <span [innerHTML]=\"data().checkboxMessage\"></span>\r\n      </mat-checkbox>\r\n    </div>\r\n  }\r\n</mat-dialog-content>\r\n\r\n<mat-dialog-actions>\r\n  @if (dialogType() !== DialogType.Choice) {\r\n    <button mat-raised-button (click)=\"close()\" [disabled]=\"dialogType() === DialogType.Input && !userInput\">\r\n      <span>\r\n        @switch (data().mode) {\r\n          @case (ConfirmationDialogMode.YesNo) {\r\n            <span>Yes</span>\r\n          }\r\n          @case (ConfirmationDialogMode.TrueFalse) {\r\n            <span>True</span>\r\n          }\r\n          @case (ConfirmationDialogMode.Custom) {\r\n            <span>{{ customTrueText }}</span>\r\n          }\r\n          @default {\r\n            <span>OK</span>\r\n          }\r\n        }\r\n      </span>\r\n    </button>\r\n    @if (dialogType() !== DialogType.Message) {\r\n      <button mat-raised-button (click)=\"cancel()\">\r\n        <span>\r\n          @switch (data().mode) {\r\n            @case (ConfirmationDialogMode.YesNo) {\r\n              <span>No</span>\r\n            }\r\n            @case (ConfirmationDialogMode.TrueFalse) {\r\n              <span>False</span>\r\n            }\r\n            @case (ConfirmationDialogMode.Custom) {\r\n              <span>{{ customFalseText }}</span>\r\n            }\r\n            @default {\r\n              <span>Cancel</span>\r\n            }\r\n          }\r\n        </span>\r\n      </button>\r\n    }\r\n  }\r\n\r\n  @if (dialogType() === DialogType.Choice) {\r\n    @for (choice of choices; track choice; let i = $index) {\r\n      <button mat-raised-button [matDialogClose]=\"i\">\r\n        <span>{{ choice }}</span>\r\n      </button>\r\n    }\r\n  }\r\n</mat-dialog-actions>", styles: ["mat-form-field{margin-top:2em;width:100%}#checkbox{margin:2em 0}\n"], dependencies: [{ kind: "directive", type: i1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "component", type: i2.MatButton, selector: "    button[mat-button], button[mat-raised-button], button[mat-flat-button],    button[mat-stroked-button]  ", exportAs: ["matButton"] }, { kind: "component", type: i3.MatCheckbox, selector: "mat-checkbox", inputs: ["aria-label", "aria-labelledby", "aria-describedby", "id", "required", "labelPosition", "name", "value", "disableRipple", "tabIndex", "color", "checked", "disabled", "indeterminate"], outputs: ["change", "indeterminateChange"], exportAs: ["matCheckbox"] }, { kind: "directive", type: i4.MatDialogClose, selector: "[mat-dialog-close], [matDialogClose]", inputs: ["aria-label", "type", "mat-dialog-close", "matDialogClose"], exportAs: ["matDialogClose"] }, { kind: "directive", type: i4.MatDialogTitle, selector: "[mat-dialog-title], [matDialogTitle]", inputs: ["id"], exportAs: ["matDialogTitle"] }, { kind: "directive", type: i4.MatDialogActions, selector: "[mat-dialog-actions], mat-dialog-actions, [matDialogActions]", inputs: ["align"] }, { kind: "directive", type: i4.MatDialogContent, selector: "[mat-dialog-content], mat-dialog-content, [matDialogContent]" }, { kind: "component", type: i5.MatFormField, selector: "mat-form-field", inputs: ["hideRequiredMarker", "color", "floatLabel", "appearance", "subscriptSizing", "hintLabel"], exportAs: ["matFormField"] }, { kind: "directive", type: i6.MatInput, selector: "input[matInput], textarea[matInput], select[matNativeControl],      input[matNativeControl], textarea[matNativeControl]", inputs: ["disabled", "id", "placeholder", "name", "required", "type", "errorStateMatcher", "aria-describedby", "value", "readonly"], exportAs: ["matInput"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: BaseComponent, decorators: [{
            type: Component,
            args: [{ selector: 'cp-dialog-base', template: "@if (data().title) {\r\n  <h2 mat-dialog-title [innerHTML]=\"data().title\"></h2>\r\n}\r\n\r\n<mat-dialog-content>\r\n  @if (data().message) {\r\n    <div [innerHTML]=\"data().message\"></div>\r\n  }\r\n\r\n  @if (dialogType() === DialogType.Input) {\r\n    <mat-form-field>\r\n      <textarea matInput [placeholder]=\"data().placeholder ?? ''\" [(ngModel)]=\"userInput\"></textarea>\r\n    </mat-form-field>\r\n  }\r\n\r\n  @if (data().checkboxMessage) {\r\n    <div id=\"checkbox\">\r\n      <mat-checkbox [(ngModel)]=\"checkboxValue\">\r\n        <span [innerHTML]=\"data().checkboxMessage\"></span>\r\n      </mat-checkbox>\r\n    </div>\r\n  }\r\n</mat-dialog-content>\r\n\r\n<mat-dialog-actions>\r\n  @if (dialogType() !== DialogType.Choice) {\r\n    <button mat-raised-button (click)=\"close()\" [disabled]=\"dialogType() === DialogType.Input && !userInput\">\r\n      <span>\r\n        @switch (data().mode) {\r\n          @case (ConfirmationDialogMode.YesNo) {\r\n            <span>Yes</span>\r\n          }\r\n          @case (ConfirmationDialogMode.TrueFalse) {\r\n            <span>True</span>\r\n          }\r\n          @case (ConfirmationDialogMode.Custom) {\r\n            <span>{{ customTrueText }}</span>\r\n          }\r\n          @default {\r\n            <span>OK</span>\r\n          }\r\n        }\r\n      </span>\r\n    </button>\r\n    @if (dialogType() !== DialogType.Message) {\r\n      <button mat-raised-button (click)=\"cancel()\">\r\n        <span>\r\n          @switch (data().mode) {\r\n            @case (ConfirmationDialogMode.YesNo) {\r\n              <span>No</span>\r\n            }\r\n            @case (ConfirmationDialogMode.TrueFalse) {\r\n              <span>False</span>\r\n            }\r\n            @case (ConfirmationDialogMode.Custom) {\r\n              <span>{{ customFalseText }}</span>\r\n            }\r\n            @default {\r\n              <span>Cancel</span>\r\n            }\r\n          }\r\n        </span>\r\n      </button>\r\n    }\r\n  }\r\n\r\n  @if (dialogType() === DialogType.Choice) {\r\n    @for (choice of choices; track choice; let i = $index) {\r\n      <button mat-raised-button [matDialogClose]=\"i\">\r\n        <span>{{ choice }}</span>\r\n      </button>\r\n    }\r\n  }\r\n</mat-dialog-actions>", styles: ["mat-form-field{margin-top:2em;width:100%}#checkbox{margin:2em 0}\n"] }]
        }], propDecorators: { closed: [{
                type: Output
            }] } });

class ChoiceComponent {
    constructor() {
        //#region Services
        this.data = inject(MAT_DIALOG_DATA);
        this.dialogRef = inject((MatDialogRef));
        //#endregion
        this.dialogType = DialogType.Choice;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: ChoiceComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.3.0", type: ChoiceComponent, selector: "cp-dialog-choice", ngImport: i0, template: "<cp-dialog-base\r\n  [data]=\"data\"\r\n  [dialogType]=\"dialogType\"\r\n  (closed)=\"dialogRef.close($event)\">\r\n</cp-dialog-base>", styles: [""], dependencies: [{ kind: "component", type: BaseComponent, selector: "cp-dialog-base", inputs: ["dialogType", "data"], outputs: ["closed"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: ChoiceComponent, decorators: [{
            type: Component,
            args: [{ selector: 'cp-dialog-choice', template: "<cp-dialog-base\r\n  [data]=\"data\"\r\n  [dialogType]=\"dialogType\"\r\n  (closed)=\"dialogRef.close($event)\">\r\n</cp-dialog-base>" }]
        }] });

class ConfirmationComponent {
    constructor() {
        //#region Services
        this.data = inject(MAT_DIALOG_DATA);
        this.dialogRef = inject((MatDialogRef));
        //#endregion
        this.dialogType = DialogType.Confirmation;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: ConfirmationComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.3.0", type: ConfirmationComponent, selector: "cp-dialog-confirmation", ngImport: i0, template: "<cp-dialog-base\r\n  [data]=\"data\"\r\n  [dialogType]=\"dialogType\"\r\n  (closed)=\"dialogRef.close($event)\">\r\n</cp-dialog-base>", styles: [""], dependencies: [{ kind: "component", type: BaseComponent, selector: "cp-dialog-base", inputs: ["dialogType", "data"], outputs: ["closed"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: ConfirmationComponent, decorators: [{
            type: Component,
            args: [{ selector: 'cp-dialog-confirmation', template: "<cp-dialog-base\r\n  [data]=\"data\"\r\n  [dialogType]=\"dialogType\"\r\n  (closed)=\"dialogRef.close($event)\">\r\n</cp-dialog-base>" }]
        }] });

class InputComponent {
    constructor() {
        //#region Services
        this.data = inject(MAT_DIALOG_DATA);
        this.dialogRef = inject((MatDialogRef));
        //#endregion
        this.dialogType = DialogType.Input;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: InputComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.3.0", type: InputComponent, selector: "cp-dialog-input", ngImport: i0, template: "<cp-dialog-base\r\n  [data]=\"data\"\r\n  [dialogType]=\"dialogType\"\r\n  (closed)=\"dialogRef.close($event)\">\r\n</cp-dialog-base>", styles: [""], dependencies: [{ kind: "component", type: BaseComponent, selector: "cp-dialog-base", inputs: ["dialogType", "data"], outputs: ["closed"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: InputComponent, decorators: [{
            type: Component,
            args: [{ selector: 'cp-dialog-input', template: "<cp-dialog-base\r\n  [data]=\"data\"\r\n  [dialogType]=\"dialogType\"\r\n  (closed)=\"dialogRef.close($event)\">\r\n</cp-dialog-base>" }]
        }] });

class MessageComponent {
    constructor() {
        //#region Services
        this.data = inject(MAT_DIALOG_DATA);
        this.dialogRef = inject((MatDialogRef));
        //#endregion
        this.dialogType = DialogType.Message;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: MessageComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.3.0", type: MessageComponent, selector: "cp-dialog-message", ngImport: i0, template: "<cp-dialog-base\r\n  [data]=\"data\"\r\n  [dialogType]=\"dialogType\"\r\n  (closed)=\"dialogRef.close($event)\">\r\n</cp-dialog-base>", styles: [""], dependencies: [{ kind: "component", type: BaseComponent, selector: "cp-dialog-base", inputs: ["dialogType", "data"], outputs: ["closed"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: MessageComponent, decorators: [{
            type: Component,
            args: [{ selector: 'cp-dialog-message', template: "<cp-dialog-base\r\n  [data]=\"data\"\r\n  [dialogType]=\"dialogType\"\r\n  (closed)=\"dialogRef.close($event)\">\r\n</cp-dialog-base>" }]
        }] });

class DialogModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DialogModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.3.0", ngImport: i0, type: DialogModule, declarations: [BaseComponent,
            ChoiceComponent,
            ConfirmationComponent,
            InputComponent,
            MessageComponent], imports: [CommonModule,
            FormsModule,
            MatButtonModule,
            MatCheckboxModule,
            MatDialogModule,
            MatFormFieldModule,
            MatInputModule], exports: [BaseComponent,
            ChoiceComponent,
            ConfirmationComponent,
            InputComponent,
            MessageComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DialogModule, imports: [CommonModule,
            FormsModule,
            MatButtonModule,
            MatCheckboxModule,
            MatDialogModule,
            MatFormFieldModule,
            MatInputModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DialogModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        BaseComponent,
                        ChoiceComponent,
                        ConfirmationComponent,
                        InputComponent,
                        MessageComponent
                    ],
                    imports: [
                        CommonModule,
                        FormsModule,
                        MatButtonModule,
                        MatCheckboxModule,
                        MatDialogModule,
                        MatFormFieldModule,
                        MatInputModule
                    ],
                    exports: [
                        BaseComponent,
                        ChoiceComponent,
                        ConfirmationComponent,
                        InputComponent,
                        MessageComponent
                    ]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { BaseComponent, ChoiceComponent, ConfirmationComponent, ConfirmationDialogMode, DialogModule, DialogType, InputComponent, MessageComponent };
//# sourceMappingURL=cleavelandprice-ngx-lib-dialog.mjs.map
