import { Buttons as Buttons$1, Config as Config$1, Icons as Icons$1, Tooltips as Tooltips$1, EditorComponent as EditorComponent$1 } from '@cleavelandprice/ngx-lib/quill';
import * as i0 from '@angular/core';
import { input, inject, forwardRef, Component, NgModule, Optional, SkipSelf } from '@angular/core';
import * as i2 from '@angular/forms';
import { NG_VALUE_ACCESSOR, FormsModule, ReactiveFormsModule } from '@angular/forms';
import { MatDialogRef, MatDialog, MatDialogModule } from '@angular/material/dialog';
import { ActiveDirectoryService } from '@cleavelandprice/ngx-lib/active-directory';
import 'quill-mention';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i3 from '@angular/material/icon';
import { MatIconModule } from '@angular/material/icon';
import * as i4 from '@angular/material/tooltip';
import { MatTooltipModule } from '@angular/material/tooltip';
import * as i5 from 'ngx-quill';
import { QuillModule } from 'ngx-quill';
import { MatButtonModule } from '@angular/material/button';

class Buttons extends Buttons$1 {
}

class Config extends Config$1 {
}

class Icons extends Icons$1 {
}

class Tooltips extends Tooltips$1 {
}

class EditorComponent extends EditorComponent$1 {
    constructor() {
        super(...arguments);
        this.users = (input);
        this.#dlgRef = inject((MatDialogRef), { optional: true });
        this.#dlg = inject(MatDialog);
        this.#activeDirectoryService = inject(ActiveDirectoryService);
    }
    #dlgRef;
    #dlg;
    #activeDirectoryService;
    ngOnInit() {
        this.initialize();
        if (!this.users()) {
            this.#activeDirectoryService.getUsers().subscribe(users => this._users = users);
        }
    }
    toggleFullscreen() {
        if (this.fullscreenMode === 'expand') {
            this.fullscreen = !this.fullscreen;
            this.fullscreenChanged.emit(this.fullscreen);
        }
        else {
            if (this.fullscreen) {
                this.#dlgRef?.close(this.value);
                this.fullscreenChanged.emit(false);
            }
            else {
                const data = {
                    value: this.value,
                    config: this.config,
                    placeholder: this.placeholder,
                    format: this.format,
                    height: this.fullscreenHeight,
                    width: '100%',
                    maxHeight: this.fullscreenHeight,
                    maxWidth: '100%',
                    enableTooltips: this.enableTooltips,
                    fullscreen: true,
                    fullscreenMode: this.fullscreenMode,
                    readonly: this.readonly,
                    applyReadonlyStyle: this.applyReadonlyStyle,
                    showToolbar: this.showToolbar,
                    showBorder: this.showBorder,
                    imageResizeModule: this.imageResizeModule,
                    imageDropModule: this.imageDropModule,
                    syntaxModule: this.syntaxModule,
                    users: this._users
                };
                this.#dlg.open(EditorComponent, {
                    disableClose: true,
                    width: this.fullscreenWidth,
                    height: this.fullscreenHeight,
                    data
                })
                    .afterClosed()
                    .subscribe(value => {
                    this.value = value;
                    this.updateChanges();
                });
                this.fullscreenChanged.emit(true);
            }
        }
    }
    get modules() {
        if (!this._users) {
            return {};
        }
        const modules = {
            mention: {
                allowedChars: /^[A-Za-z\sÅÄÖåäö]*$/,
                onSelect: (item, insertItem) => {
                    const editor = this.editor.quillEditor;
                    insertItem(item);
                    // necessary because quill-mention triggers changes as 'api' instead of 'user'
                    editor.insertText(editor.getLength() - 1, '', 'user');
                },
                source: (searchTerm, renderList) => {
                    if (searchTerm.length === 0) {
                        renderList(this._users?.map(u => ({ value: `${u.displayName} (${u.sAMAccountName.toLowerCase()})` })), searchTerm);
                    }
                    else {
                        const matches = [];
                        this._users.forEach((entry) => {
                            if (entry.displayName.toLowerCase().indexOf(searchTerm.toLowerCase()) !== -1 ||
                                entry.sAMAccountName.toLowerCase().indexOf(searchTerm.toLowerCase()) !== -1) {
                                matches.push({ value: `${entry.displayName} (${entry.sAMAccountName.toLowerCase()})` });
                            }
                        });
                        renderList(matches, searchTerm);
                    }
                }
            }
        };
        if (!this.showToolbar) {
            modules['toolbar'] = [];
        }
        if (this.imageResizeModule) {
            modules['imageResize'] = {};
        }
        if (this.imageDropModule) {
            modules['imageDrop'] = true;
        }
        if (this.syntaxModule) {
            modules['syntax'] = true;
        }
        return modules;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: EditorComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "17.3.0", type: EditorComponent, selector: "cpquill-editor-with-mention", providers: [{
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => EditorComponent),
                multi: true
            }], usesInheritance: true, ngImport: i0, template: "@if (_users) {\r\n  <form>\r\n    <quill-editor name=\"editor\"\r\n      [(ngModel)]=\"value\"\r\n      (ngModelChange)=\"updateChanges()\"\r\n      [placeholder]=\"placeholder\"\r\n      [format]=\"format\"\r\n      [style.height]=\"fullscreen ? fullscreenHeight : height\"\r\n      [style.width]=\"fullscreen ? fullscreenWidth : width\"\r\n      [readOnly]=\"readonly\"\r\n      [class.readonly]=\"readonly && applyReadonlyStyle\"\r\n      [class.no-toolbar]=\"!showToolbar\"\r\n      [class.no-border]=\"!showBorder\"\r\n      [modules]=\"modules\"\r\n      (onBlur)=\"onBlur.emit($event)\"\r\n      (onContentChanged)=\"onContentChanged.emit($event)\"\r\n      (onEditorChanged)=\"onEditorChanged.emit($event)\"\r\n      (onEditorCreated)=\"onEditorCreated.emit()\"\r\n      (onFocus)=\"onFocus.emit($event)\"\r\n      (onSelectionChanged)=\"onSelectionChanged.emit($event)\">\r\n      @if (showToolbar) {\r\n        <div quill-editor-toolbar>\r\n          <ng-container [ngTemplateOutlet]=\"toolbar\"/>\r\n          <ng-container [ngTemplateOutlet]=\"editorSize\"/>\r\n        </div>\r\n      }\r\n    </quill-editor>\r\n  </form>\r\n}\r\n\r\n<ng-template #toolbar>\r\n  <div>\r\n    <ng-container [ngTemplateOutlet]=\"fontStyle\"/>\r\n    <ng-container [ngTemplateOutlet]=\"blockStyle\"/>\r\n    <ng-container [ngTemplateOutlet]=\"headingStyle\"/>\r\n    <ng-container [ngTemplateOutlet]=\"listStyle\"/>\r\n    <ng-container [ngTemplateOutlet]=\"scriptStyle\"/>\r\n    <ng-container [ngTemplateOutlet]=\"indentStyle\"/>\r\n    <ng-container [ngTemplateOutlet]=\"rtl\"/>\r\n    <ng-container [ngTemplateOutlet]=\"fontSize\"/>\r\n    <ng-container [ngTemplateOutlet]=\"heading\"/>\r\n    <ng-container [ngTemplateOutlet]=\"color\"/>\r\n    <ng-container [ngTemplateOutlet]=\"font\"/>\r\n    <ng-container [ngTemplateOutlet]=\"align\"/>\r\n    <ng-container [ngTemplateOutlet]=\"clean\"/>\r\n    <ng-container [ngTemplateOutlet]=\"formula\"/>\r\n    <ng-container [ngTemplateOutlet]=\"media\"/>\r\n  </div>\r\n</ng-template>\r\n\r\n<ng-template #fontStyle>\r\n  @if (config!.showFontStyle()) {\r\n    <span class=\"ql-formats\">\r\n      @if (config!.buttons.bold) {\r\n        <button class=\"ql-bold\"           [matTooltip]=\"tooltip(config!.tooltips.bold)\"></button>\r\n      }\r\n      @if (config!.buttons.italic) {\r\n        <button class=\"ql-italic\"       [matTooltip]=\"tooltip(config!.tooltips.italic)\"></button>\r\n      }\r\n      @if (config!.buttons.underline) {\r\n        <button class=\"ql-underline\" [matTooltip]=\"tooltip(config!.tooltips.underline)\"></button>\r\n      }\r\n      @if (config!.buttons.strike) {\r\n        <button class=\"ql-strike\"       [matTooltip]=\"tooltip(config!.tooltips.strike)\"></button>\r\n      }\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #blockStyle>\r\n  @if (config!.showBlockStyle()) {\r\n    <span class=\"ql-formats\">\r\n      @if (config!.buttons.blockquote) {\r\n        <button class=\"ql-blockquote\" [matTooltip]=\"tooltip(config!.tooltips.blockquote)\"></button>\r\n      }\r\n      @if (config!.buttons.codeblock) {\r\n        <button class=\"ql-code-block\"  [matTooltip]=\"tooltip(config!.tooltips.codeblock)\"></button>\r\n      }\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #headingStyle>\r\n  @if (config!.showQuickHeadingStyle()) {\r\n    <span class=\"ql-formats\">\r\n      @if (config!.buttons.h1) {\r\n        <button class=\"ql-header\" value=\"1\" [matTooltip]=\"tooltip(config!.tooltips.h1)\"></button>\r\n      }\r\n      @if (config!.buttons.h2) {\r\n        <button class=\"ql-header\" value=\"2\" [matTooltip]=\"tooltip(config!.tooltips.h2)\"></button>\r\n      }\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #listStyle>\r\n  @if (config!.showListStyle()) {\r\n    <span class=\"ql-formats\">\r\n      @if (config!.buttons.ordered) {\r\n        <button class=\"ql-list\" value=\"ordered\"  [matTooltip]=\"tooltip(config!.tooltips.ordered)\"></button>\r\n      }\r\n      @if (config!.buttons.bulleted) {\r\n        <button class=\"ql-list\" value=\"bullet\"  [matTooltip]=\"tooltip(config!.tooltips.bulleted)\"></button>\r\n      }\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #scriptStyle>\r\n  @if (config!.showScriptStyle()) {\r\n    <span class=\"ql-formats\">\r\n      @if (config!.buttons.subScript) {\r\n        <button class=\"ql-script\" value=\"sub\"   [matTooltip]=\"tooltip(config!.tooltips.subScript)\"></button>\r\n      }\r\n      @if (config!.buttons.superScript) {\r\n        <button class=\"ql-script\" value=\"super\" [matTooltip]=\"tooltip(config!.tooltips.superScript)\"></button>\r\n      }\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #indentStyle>\r\n  @if (config!.showIndentStyle()) {\r\n    <span class=\"ql-formats\">\r\n      @if (config!.buttons.decreaseIndent) {\r\n        <button class=\"ql-indent\" value=\"-1\" [matTooltip]=\"tooltip(config!.tooltips.decreaseIndent)\"></button>\r\n      }\r\n      @if (config!.buttons.increaseIndent) {\r\n        <button class=\"ql-indent\" value=\"+1\" [matTooltip]=\"tooltip(config!.tooltips.increaseIndent)\"></button>\r\n      }\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #rtl>\r\n  @if (config!.buttons.rtl) {\r\n    <span class=\"ql-formats\">\r\n      <button class=\"ql-direction\" value=\"rtl\" [matTooltip]=\"tooltip(config!.tooltips.rtl)\"></button>\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #fontSize>\r\n  @if (config!.buttons.fontSize) {\r\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config!.tooltips.fontSize)\">\r\n      <select class=\"ql-size\">\r\n        <option value=\"small\"></option>\r\n        <option selected></option>\r\n        <option value=\"large\"></option>\r\n        <option value=\"huge\"></option>\r\n      </select>\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #heading>\r\n  @if (config!.buttons.headingStyle) {\r\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config!.tooltips.headingStyle)\">\r\n      <select class=\"ql-header\">\r\n        <option value=\"1\"></option>\r\n        <option value=\"2\"></option>\r\n        <option value=\"3\"></option>\r\n        <option value=\"4\"></option>\r\n        <option value=\"5\"></option>\r\n        <option value=\"6\"></option>\r\n        <option selected=\"selected\"></option>\r\n      </select>\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #color>\r\n  @if (config!.buttons.color) {\r\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config!.tooltips.color)\">\r\n      <select class=\"ql-color\"></select>\r\n      <select class=\"ql-background\"></select>\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #font>\r\n  @if (config!.buttons.font) {\r\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config!.tooltips.font)\">\r\n      <select class=\"ql-font\">\r\n        <option selected></option>\r\n        <option value=\"serif\"></option>\r\n        <option value=\"monospace\"></option>\r\n      </select>\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #align>\r\n  @if (config!.buttons.align) {\r\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config!.tooltips.align)\">\r\n      <select class=\"ql-align\">\r\n        <option selected></option>\r\n        <option value=\"center\"></option>\r\n        <option value=\"right\"></option>\r\n        <option value=\"justify\"></option>\r\n      </select>\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #clean>\r\n  @if (config!.buttons.clean) {\r\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config!.tooltips.clean)\">\r\n      <button class=\"ql-clean\"></button>\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #media>\r\n  @if (config!.showMedia()) {\r\n    <span class=\"ql-formats\">\r\n      @if (config!.buttons.link) {\r\n        <button class=\"ql-link\"  [matTooltip]=\"tooltip(config!.tooltips.link)\"></button>\r\n      }\r\n      @if (config!.buttons.image) {\r\n        <button class=\"ql-image\" [matTooltip]=\"tooltip(config!.tooltips.image)\"></button>\r\n      }\r\n      @if (config!.buttons.video) {\r\n        <button class=\"ql-video\" [matTooltip]=\"tooltip(config!.tooltips.video)\"></button>\r\n      }\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #editorSize>\r\n  <div>\r\n    @if (config!.buttons.rawEditor) {\r\n      <span class=\"ql-formats\">\r\n        <button id=\"rawdog\"\r\n          [matTooltip]=\"tooltip(config!.tooltips.rawEditor)\">\r\n          <mat-icon (click)=\"rawEdit()\">\r\n            code\r\n          </mat-icon>\r\n        </button>\r\n      </span>\r\n    }\r\n\r\n    @if (config!.buttons.editorSize) {\r\n      <span class=\"ql-formats\">\r\n        <button id=\"fullscreen\"\r\n                [matTooltip]=\"tooltip(fullscreen ?\r\n                    (fullscreenMode === 'expand' ? config!.tooltips.minimize : config!.tooltips.popin) :\r\n                    (fullscreenMode === 'expand' ? config!.tooltips.maximize : config!.tooltips.popout))\">\r\n          <mat-icon (click)=\"toggleFullscreen()\">\r\n            {{ fullscreen ?\r\n            (fullscreenMode === 'expand' ? config!.icons.minimize : config!.icons.popin) :\r\n            (fullscreenMode === 'expand' ? config!.icons.maximize : config!.icons.popout)\r\n            }}\r\n          </mat-icon>\r\n        </button>\r\n      </span>\r\n    }\r\n  </div>\r\n</ng-template>\r\n\r\n<ng-template #formula>\r\n  @if (config!.buttons.formula) {\r\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config!.tooltips.formula)\">\r\n      <button class=\"ql-formula\"></button>\r\n    </span>\r\n  }\r\n</ng-template>", styles: [".ql-toolbar{display:grid;grid-template-columns:1fr auto}mat-icon{color:#ff4500}quill-editor.readonly .ql-toolbar{opacity:.5}::ng-deep quill-editor.no-toolbar .ql-toolbar{height:0;padding:0;visibility:hidden}::ng-deep quill-editor.no-border .ql-container{border:none}::ng-deep quill-editor.readonly .ql-container{background-color:#f5f5f5!important}\n"], dependencies: [{ kind: "directive", type: i1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "directive", type: i2.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i2.NgSelectOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i2.ɵNgSelectMultipleOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "directive", type: i2.NgForm, selector: "form:not([ngNoForm]):not([formGroup]),ng-form,[ngForm]", inputs: ["ngFormOptions"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "component", type: i3.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { kind: "directive", type: i4.MatTooltip, selector: "[matTooltip]", inputs: ["matTooltipPosition", "matTooltipPositionAtOrigin", "matTooltipDisabled", "matTooltipShowDelay", "matTooltipHideDelay", "matTooltipTouchGestures", "matTooltip", "matTooltipClass"], exportAs: ["matTooltip"] }, { kind: "component", type: i5.QuillEditorComponent, selector: "quill-editor" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: EditorComponent, decorators: [{
            type: Component,
            args: [{ selector: 'cpquill-editor-with-mention', providers: [{
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => EditorComponent),
                            multi: true
                        }], template: "@if (_users) {\r\n  <form>\r\n    <quill-editor name=\"editor\"\r\n      [(ngModel)]=\"value\"\r\n      (ngModelChange)=\"updateChanges()\"\r\n      [placeholder]=\"placeholder\"\r\n      [format]=\"format\"\r\n      [style.height]=\"fullscreen ? fullscreenHeight : height\"\r\n      [style.width]=\"fullscreen ? fullscreenWidth : width\"\r\n      [readOnly]=\"readonly\"\r\n      [class.readonly]=\"readonly && applyReadonlyStyle\"\r\n      [class.no-toolbar]=\"!showToolbar\"\r\n      [class.no-border]=\"!showBorder\"\r\n      [modules]=\"modules\"\r\n      (onBlur)=\"onBlur.emit($event)\"\r\n      (onContentChanged)=\"onContentChanged.emit($event)\"\r\n      (onEditorChanged)=\"onEditorChanged.emit($event)\"\r\n      (onEditorCreated)=\"onEditorCreated.emit()\"\r\n      (onFocus)=\"onFocus.emit($event)\"\r\n      (onSelectionChanged)=\"onSelectionChanged.emit($event)\">\r\n      @if (showToolbar) {\r\n        <div quill-editor-toolbar>\r\n          <ng-container [ngTemplateOutlet]=\"toolbar\"/>\r\n          <ng-container [ngTemplateOutlet]=\"editorSize\"/>\r\n        </div>\r\n      }\r\n    </quill-editor>\r\n  </form>\r\n}\r\n\r\n<ng-template #toolbar>\r\n  <div>\r\n    <ng-container [ngTemplateOutlet]=\"fontStyle\"/>\r\n    <ng-container [ngTemplateOutlet]=\"blockStyle\"/>\r\n    <ng-container [ngTemplateOutlet]=\"headingStyle\"/>\r\n    <ng-container [ngTemplateOutlet]=\"listStyle\"/>\r\n    <ng-container [ngTemplateOutlet]=\"scriptStyle\"/>\r\n    <ng-container [ngTemplateOutlet]=\"indentStyle\"/>\r\n    <ng-container [ngTemplateOutlet]=\"rtl\"/>\r\n    <ng-container [ngTemplateOutlet]=\"fontSize\"/>\r\n    <ng-container [ngTemplateOutlet]=\"heading\"/>\r\n    <ng-container [ngTemplateOutlet]=\"color\"/>\r\n    <ng-container [ngTemplateOutlet]=\"font\"/>\r\n    <ng-container [ngTemplateOutlet]=\"align\"/>\r\n    <ng-container [ngTemplateOutlet]=\"clean\"/>\r\n    <ng-container [ngTemplateOutlet]=\"formula\"/>\r\n    <ng-container [ngTemplateOutlet]=\"media\"/>\r\n  </div>\r\n</ng-template>\r\n\r\n<ng-template #fontStyle>\r\n  @if (config!.showFontStyle()) {\r\n    <span class=\"ql-formats\">\r\n      @if (config!.buttons.bold) {\r\n        <button class=\"ql-bold\"           [matTooltip]=\"tooltip(config!.tooltips.bold)\"></button>\r\n      }\r\n      @if (config!.buttons.italic) {\r\n        <button class=\"ql-italic\"       [matTooltip]=\"tooltip(config!.tooltips.italic)\"></button>\r\n      }\r\n      @if (config!.buttons.underline) {\r\n        <button class=\"ql-underline\" [matTooltip]=\"tooltip(config!.tooltips.underline)\"></button>\r\n      }\r\n      @if (config!.buttons.strike) {\r\n        <button class=\"ql-strike\"       [matTooltip]=\"tooltip(config!.tooltips.strike)\"></button>\r\n      }\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #blockStyle>\r\n  @if (config!.showBlockStyle()) {\r\n    <span class=\"ql-formats\">\r\n      @if (config!.buttons.blockquote) {\r\n        <button class=\"ql-blockquote\" [matTooltip]=\"tooltip(config!.tooltips.blockquote)\"></button>\r\n      }\r\n      @if (config!.buttons.codeblock) {\r\n        <button class=\"ql-code-block\"  [matTooltip]=\"tooltip(config!.tooltips.codeblock)\"></button>\r\n      }\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #headingStyle>\r\n  @if (config!.showQuickHeadingStyle()) {\r\n    <span class=\"ql-formats\">\r\n      @if (config!.buttons.h1) {\r\n        <button class=\"ql-header\" value=\"1\" [matTooltip]=\"tooltip(config!.tooltips.h1)\"></button>\r\n      }\r\n      @if (config!.buttons.h2) {\r\n        <button class=\"ql-header\" value=\"2\" [matTooltip]=\"tooltip(config!.tooltips.h2)\"></button>\r\n      }\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #listStyle>\r\n  @if (config!.showListStyle()) {\r\n    <span class=\"ql-formats\">\r\n      @if (config!.buttons.ordered) {\r\n        <button class=\"ql-list\" value=\"ordered\"  [matTooltip]=\"tooltip(config!.tooltips.ordered)\"></button>\r\n      }\r\n      @if (config!.buttons.bulleted) {\r\n        <button class=\"ql-list\" value=\"bullet\"  [matTooltip]=\"tooltip(config!.tooltips.bulleted)\"></button>\r\n      }\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #scriptStyle>\r\n  @if (config!.showScriptStyle()) {\r\n    <span class=\"ql-formats\">\r\n      @if (config!.buttons.subScript) {\r\n        <button class=\"ql-script\" value=\"sub\"   [matTooltip]=\"tooltip(config!.tooltips.subScript)\"></button>\r\n      }\r\n      @if (config!.buttons.superScript) {\r\n        <button class=\"ql-script\" value=\"super\" [matTooltip]=\"tooltip(config!.tooltips.superScript)\"></button>\r\n      }\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #indentStyle>\r\n  @if (config!.showIndentStyle()) {\r\n    <span class=\"ql-formats\">\r\n      @if (config!.buttons.decreaseIndent) {\r\n        <button class=\"ql-indent\" value=\"-1\" [matTooltip]=\"tooltip(config!.tooltips.decreaseIndent)\"></button>\r\n      }\r\n      @if (config!.buttons.increaseIndent) {\r\n        <button class=\"ql-indent\" value=\"+1\" [matTooltip]=\"tooltip(config!.tooltips.increaseIndent)\"></button>\r\n      }\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #rtl>\r\n  @if (config!.buttons.rtl) {\r\n    <span class=\"ql-formats\">\r\n      <button class=\"ql-direction\" value=\"rtl\" [matTooltip]=\"tooltip(config!.tooltips.rtl)\"></button>\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #fontSize>\r\n  @if (config!.buttons.fontSize) {\r\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config!.tooltips.fontSize)\">\r\n      <select class=\"ql-size\">\r\n        <option value=\"small\"></option>\r\n        <option selected></option>\r\n        <option value=\"large\"></option>\r\n        <option value=\"huge\"></option>\r\n      </select>\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #heading>\r\n  @if (config!.buttons.headingStyle) {\r\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config!.tooltips.headingStyle)\">\r\n      <select class=\"ql-header\">\r\n        <option value=\"1\"></option>\r\n        <option value=\"2\"></option>\r\n        <option value=\"3\"></option>\r\n        <option value=\"4\"></option>\r\n        <option value=\"5\"></option>\r\n        <option value=\"6\"></option>\r\n        <option selected=\"selected\"></option>\r\n      </select>\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #color>\r\n  @if (config!.buttons.color) {\r\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config!.tooltips.color)\">\r\n      <select class=\"ql-color\"></select>\r\n      <select class=\"ql-background\"></select>\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #font>\r\n  @if (config!.buttons.font) {\r\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config!.tooltips.font)\">\r\n      <select class=\"ql-font\">\r\n        <option selected></option>\r\n        <option value=\"serif\"></option>\r\n        <option value=\"monospace\"></option>\r\n      </select>\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #align>\r\n  @if (config!.buttons.align) {\r\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config!.tooltips.align)\">\r\n      <select class=\"ql-align\">\r\n        <option selected></option>\r\n        <option value=\"center\"></option>\r\n        <option value=\"right\"></option>\r\n        <option value=\"justify\"></option>\r\n      </select>\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #clean>\r\n  @if (config!.buttons.clean) {\r\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config!.tooltips.clean)\">\r\n      <button class=\"ql-clean\"></button>\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #media>\r\n  @if (config!.showMedia()) {\r\n    <span class=\"ql-formats\">\r\n      @if (config!.buttons.link) {\r\n        <button class=\"ql-link\"  [matTooltip]=\"tooltip(config!.tooltips.link)\"></button>\r\n      }\r\n      @if (config!.buttons.image) {\r\n        <button class=\"ql-image\" [matTooltip]=\"tooltip(config!.tooltips.image)\"></button>\r\n      }\r\n      @if (config!.buttons.video) {\r\n        <button class=\"ql-video\" [matTooltip]=\"tooltip(config!.tooltips.video)\"></button>\r\n      }\r\n    </span>\r\n  }\r\n</ng-template>\r\n\r\n<ng-template #editorSize>\r\n  <div>\r\n    @if (config!.buttons.rawEditor) {\r\n      <span class=\"ql-formats\">\r\n        <button id=\"rawdog\"\r\n          [matTooltip]=\"tooltip(config!.tooltips.rawEditor)\">\r\n          <mat-icon (click)=\"rawEdit()\">\r\n            code\r\n          </mat-icon>\r\n        </button>\r\n      </span>\r\n    }\r\n\r\n    @if (config!.buttons.editorSize) {\r\n      <span class=\"ql-formats\">\r\n        <button id=\"fullscreen\"\r\n                [matTooltip]=\"tooltip(fullscreen ?\r\n                    (fullscreenMode === 'expand' ? config!.tooltips.minimize : config!.tooltips.popin) :\r\n                    (fullscreenMode === 'expand' ? config!.tooltips.maximize : config!.tooltips.popout))\">\r\n          <mat-icon (click)=\"toggleFullscreen()\">\r\n            {{ fullscreen ?\r\n            (fullscreenMode === 'expand' ? config!.icons.minimize : config!.icons.popin) :\r\n            (fullscreenMode === 'expand' ? config!.icons.maximize : config!.icons.popout)\r\n            }}\r\n          </mat-icon>\r\n        </button>\r\n      </span>\r\n    }\r\n  </div>\r\n</ng-template>\r\n\r\n<ng-template #formula>\r\n  @if (config!.buttons.formula) {\r\n    <span class=\"ql-formats\" [matTooltip]=\"tooltip(config!.tooltips.formula)\">\r\n      <button class=\"ql-formula\"></button>\r\n    </span>\r\n  }\r\n</ng-template>", styles: [".ql-toolbar{display:grid;grid-template-columns:1fr auto}mat-icon{color:#ff4500}quill-editor.readonly .ql-toolbar{opacity:.5}::ng-deep quill-editor.no-toolbar .ql-toolbar{height:0;padding:0;visibility:hidden}::ng-deep quill-editor.no-border .ql-container{border:none}::ng-deep quill-editor.readonly .ql-container{background-color:#f5f5f5!important}\n"] }]
        }] });

class QuillMentionModule {
    static forRoot() {
        return {
            ngModule: QuillMentionModule
        };
    }
    constructor(parentModule) {
        if (parentModule) {
            throw new Error('QuillMentionModule is already loaded. Import it in the AppModule only');
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: QuillMentionModule, deps: [{ token: QuillMentionModule, optional: true, skipSelf: true }], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.3.0", ngImport: i0, type: QuillMentionModule, declarations: [EditorComponent], imports: [CommonModule,
            FormsModule,
            ReactiveFormsModule,
            MatButtonModule,
            MatDialogModule,
            MatIconModule,
            MatTooltipModule, i5.QuillModule], exports: [EditorComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: QuillMentionModule, imports: [CommonModule,
            FormsModule,
            ReactiveFormsModule,
            MatButtonModule,
            MatDialogModule,
            MatIconModule,
            MatTooltipModule,
            QuillModule.forRoot()] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: QuillMentionModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        EditorComponent
                    ],
                    imports: [
                        CommonModule,
                        FormsModule,
                        ReactiveFormsModule,
                        MatButtonModule,
                        MatDialogModule,
                        MatIconModule,
                        MatTooltipModule,
                        QuillModule.forRoot()
                    ],
                    exports: [
                        EditorComponent
                    ]
                }]
        }], ctorParameters: () => [{ type: QuillMentionModule, decorators: [{
                    type: Optional
                }, {
                    type: SkipSelf
                }] }] });

/**
 * Generated bundle index. Do not edit.
 */

export { Buttons, Config, EditorComponent, Icons, QuillMentionModule, Tooltips };
//# sourceMappingURL=cleavelandprice-ngx-lib-quill-mention.mjs.map
