import * as i0 from '@angular/core';
import { EventEmitter, Component, Input, Output, ViewChild, NgModule } from '@angular/core';
import * as i7 from '@angular/material/table';
import { MatTableDataSource, MatTableModule } from '@angular/material/table';
import * as i9 from '@angular/material/paginator';
import { MatPaginator, MatPaginatorModule } from '@angular/material/paginator';
import * as i8 from '@angular/material/sort';
import { MatSort, MatSortModule } from '@angular/material/sort';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i2 from '@angular/forms';
import { FormsModule, ReactiveFormsModule } from '@angular/forms';
import * as i3 from '@angular/material/button';
import { MatButtonModule } from '@angular/material/button';
import * as i4 from '@angular/material/checkbox';
import { MatCheckboxModule } from '@angular/material/checkbox';
import * as i5 from '@angular/material/form-field';
import { MatFormFieldModule } from '@angular/material/form-field';
import * as i6 from '@angular/material/input';
import { MatInputModule } from '@angular/material/input';
import * as i10 from '@angular/material/tooltip';
import { MatTooltipModule } from '@angular/material/tooltip';
import * as i11 from '@angular/material/icon';
import { MatIconModule } from '@angular/material/icon';

class TableComponent {
    get columnNames() {
        return this.columns.map(c => c.field);
    }
    set matSort(ms) {
        this.sort = ms;
        this.dataSource.paginator = this.paginator;
        this.dataSource.sort = this.sort;
    }
    set matPaginator(mp) {
        this.paginator = mp;
        this.dataSource.paginator = this.paginator;
        this.dataSource.sort = this.sort;
    }
    constructor() {
        this.title = '';
        this.tableData = [];
        this.columns = [];
        this.showPaginator = true;
        this.showSearch = true;
        // @Input() pageSizeOptions: number[] = [10, 20, 100, 500, this.tableData.length];
        this.maxTableHeight = '50em';
        this.shrinkTableRowHeight = false;
        this.paginatorSticky = false;
        this.isMobile = false;
        this.buttonClicked = new EventEmitter();
        this.dataSource = new MatTableDataSource([]);
        this.pageSizeOptions = [10, 20, 100, 500];
        this.paginator = null;
        this.sort = null;
    }
    ngOnInit() {
        this.dataSource.data = this.tableData;
        this.setTablePageSizeOptions();
    }
    searchFilterChange(event) {
        const filterValue = event.target.value;
        this.dataSource.filter = filterValue.trim().toLowerCase();
    }
    buttonClick(rowData, field) {
        this.buttonClicked.emit({ rowData, field });
    }
    getNestedFieldValue(rowData, nestedFieldName) {
        if (!nestedFieldName) {
            return;
        }
        return rowData[nestedFieldName];
    }
    setTablePageSizeOptions(defaultPageIncrement = 50) {
        this.pageSizeOptions = [];
        for (let i = defaultPageIncrement; i < this.dataSource.data.length; i = i + (defaultPageIncrement * 2)) {
            this.pageSizeOptions.push(i);
        }
        this.pageSizeOptions.push(this.dataSource.data.length);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: TableComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.3.0", type: TableComponent, selector: "lib-table", inputs: { title: "title", tableData: "tableData", columns: "columns", showPaginator: "showPaginator", showSearch: "showSearch", maxTableHeight: "maxTableHeight", shrinkTableRowHeight: "shrinkTableRowHeight", paginatorSticky: "paginatorSticky" }, outputs: { buttonClicked: "buttonClicked" }, viewQueries: [{ propertyName: "matSort", first: true, predicate: MatSort, descendants: true }, { propertyName: "matPaginator", first: true, predicate: MatPaginator, descendants: true }], ngImport: i0, template: "<h3>{{title}}</h3>\r\n\r\n<mat-form-field appearance=\"outline\" *ngIf=\"showSearch\">\r\n    <mat-label>Search</mat-label>\r\n    <mat-icon matPrefix>search</mat-icon>\r\n    <input type=\"text\" matInput (keyup)=\"searchFilterChange($event)\">\r\n</mat-form-field>\r\n\r\n<div class=\"table-container\" [ngStyle]=\"{'max-height': maxTableHeight}\">\r\n    <table mat-table [dataSource]=\"dataSource\" matSort>\r\n      <ng-container *ngFor=\"let column of columns\" [matColumnDef]=\"column.field\">\r\n        <th mat-header-cell *matHeaderCellDef mat-sort-header [class.hide-mobile]=\"column.hideOnMobile && isMobile\" [ngStyle]=\"{ 'width': column.columnWidth }\">\r\n          <div>{{ column.fieldColumnTitle }}</div>\r\n        </th>\r\n\r\n        <td mat-cell *matCellDef=\"let data\" [class.hide-mobile]=\"column.hideOnMobile && isMobile\" [ngStyle]=\"{ 'width': column.columnWidth }\">\r\n          <span *ngIf=\"!column.isDate &&\r\n            !column.isPercent &&\r\n            !column.isNumber &&\r\n            !column.isCheckbox &&\r\n            !column.isButton &&\r\n            !column.isEditable &&\r\n            !column.nestedField &&\r\n            !column.isHyperlink\"\r\n          >\r\n            {{ data[column.field] }}\r\n          </span>\r\n\r\n          <span *ngIf=\"column.isHyperlink\">\r\n            <a [href]=\"data[column.isHyperlink.linkField]\" target=\"_blank\">\r\n              {{ data[column.field] }}\r\n            </a>\r\n          </span>\r\n\r\n          <span *ngIf=\"column.isDate\">\r\n            {{ data[column.field] | date:'shortDate' }}\r\n          </span>\r\n\r\n          <span *ngIf=\"column.isNumber && !column.isNumber.needsRounded && !column.isNumber.percentage\">\r\n            {{ data[column.field] | number:'.1-2' }}\r\n          </span>\r\n          <span *ngIf=\"column.isNumber && column.isNumber.needsRounded && !column.isNumber.percentage\">\r\n            {{ data[column.field] | number:'0.0-0' }}\r\n          </span>\r\n          <span *ngIf=\"column.isNumber && column.isNumber.needsRounded && column.isNumber.percentage\">\r\n            {{ data[column.field] | number:'0.0-0' }}%\r\n          </span>\r\n          <span *ngIf=\"column.isNumber && !column.isNumber.needsRounded && column.isNumber.percentage\">\r\n            {{ data[column.field] | number:'.1-2' }}%\r\n          </span>\r\n\r\n          <span *ngIf=\"column.isCheckbox\">\r\n            <mat-checkbox *ngIf=\"!column.isCheckbox['isDisabled']\"\r\n              [(ngModel)]=\"data[column.field]\">\r\n            </mat-checkbox>\r\n\r\n            <mat-checkbox *ngIf=\"column.isCheckbox['isDisabled']\"\r\n              [(ngModel)]=\"data[column.field]\"\r\n              disabled>\r\n            </mat-checkbox>\r\n          </span>\r\n\r\n          <span *ngIf=\"column.nestedField\">\r\n            {{ getNestedFieldValue(data[column.field], column.nestedField) }}\r\n          </span>\r\n\r\n          <span *ngIf=\"column.isButton\">\r\n            <button mat-icon-button *ngIf=\"column.isButton.isIcon && !column.isButton.isDisabled\"\r\n              [matTooltip]=\"column.isButton.isIcon.toolTip\"\r\n              (click)=\"buttonClick(data, column.field)\">\r\n              <mat-icon>{{column.isButton.isIcon.iconName}}</mat-icon>\r\n            </button>\r\n\r\n            <button mat-icon-button *ngIf=\"column.isButton.isIcon && column.isButton.isDisabled\" [matTooltip]=\"column.isButton.isIcon.toolTip\" disabled>\r\n              <mat-icon>{{column.isButton.isIcon.iconName}}</mat-icon>\r\n            </button>\r\n\r\n            <button mat-raised-button *ngIf=\"column.isButton && column.isButton.isDisabled && !column.isButton.isIcon && !column.isButton.isCheckbox\" disabled>\r\n              {{column.isButton.text}}\r\n            </button>\r\n\r\n            <button mat-raised-button color=\"primary\" *ngIf=\"column.isButton && !column.isButton.isDisabled && !column.isButton.isIcon && !column.isButton.isCheckbox\"\r\n              [ngClass]=\"{ 'button-extra-padding': column.isButton.extraPadding }\"\r\n              (click)=\"buttonClick(data, column.field)\">\r\n              {{column.isButton.text}}\r\n            </button>\r\n\r\n            <mat-checkbox *ngIf=\"column.isButton.isCheckbox\" [matTooltip]=\"column.isButton.isCheckbox.toolTip\"\r\n              [(ngModel)]=\"data[column.field]\" (click)=\"buttonClick(data, column.field)\">\r\n            </mat-checkbox>\r\n          </span>\r\n\r\n          <span *ngIf=\"column.isEditable\">\r\n            <textarea *ngIf=\"column.isEditable && column.isEditable.type === 'textarea'\" style=\"width: 100%;\" [rows]=\"3\" [(ngModel)]=\"data[column.field]\" [disabled]=\"column.isEditable.disable !== undefined && column.isEditable.disable\"></textarea>\r\n            <input *ngIf=\"column.isEditable && column.isEditable.type === 'input'\" [(ngModel)]=\"data[column.field]\" style=\"width: 55%;\"  [disabled]=\"column.isEditable.disable !== undefined && column.isEditable.disable\" [type]=\"column.isEditable.isNumber ? 'number' : 'text'\">\r\n          </span>\r\n        </td>\r\n      </ng-container>\r\n\r\n      <tr mat-header-row *matHeaderRowDef=\"columnNames; sticky: true\"></tr>\r\n      <tr mat-row *matRowDef=\"let row; columns: columnNames;\" class=\"table-row\" [ngClass]=\"{'shrink-table-row': shrinkTableRowHeight}\"></tr>\r\n      <tr mat-row *matNoDataRow>\r\n        <td class=\"mat-cell\" colspan=\"9999\">\r\n          No records exist.\r\n        </td>\r\n      </tr>\r\n    </table>\r\n    <mat-paginator *ngIf=\"showPaginator\" [ngClass]=\"{ 'paginator-sticky': paginatorSticky }\" [pageSizeOptions]=\"pageSizeOptions\" showFirstLastButtons></mat-paginator>\r\n</div>\r\n", styles: [".mat-form-field{width:100%!important}.table-container{display:grid;grid-template-columns:1fr;max-height:50em;overflow:auto;margin:1em .5em .5em;text-align:center!important}.table-container .table{width:100%}:host ::ng-deep .mat-sort-header-container{display:flex;justify-content:center}td,th{text-align:center!important}.shrink-table-row{height:.1em!important;min-height:.1em!important}.paginator-sticky{bottom:0;position:sticky;z-index:10}.button-extra-padding{padding-top:1.75em;padding-bottom:1.75em}\n"], dependencies: [{ kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i1.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }, { kind: "directive", type: i2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "component", type: i3.MatButton, selector: "    button[mat-button], button[mat-raised-button], button[mat-flat-button],    button[mat-stroked-button]  ", exportAs: ["matButton"] }, { kind: "component", type: i3.MatIconButton, selector: "button[mat-icon-button]", exportAs: ["matButton"] }, { kind: "component", type: i4.MatCheckbox, selector: "mat-checkbox", inputs: ["aria-label", "aria-labelledby", "aria-describedby", "id", "required", "labelPosition", "name", "value", "disableRipple", "tabIndex", "color", "checked", "disabled", "indeterminate"], outputs: ["change", "indeterminateChange"], exportAs: ["matCheckbox"] }, { kind: "component", type: i5.MatFormField, selector: "mat-form-field", inputs: ["hideRequiredMarker", "color", "floatLabel", "appearance", "subscriptSizing", "hintLabel"], exportAs: ["matFormField"] }, { kind: "directive", type: i5.MatLabel, selector: "mat-label" }, { kind: "directive", type: i5.MatPrefix, selector: "[matPrefix], [matIconPrefix], [matTextPrefix]", inputs: ["matTextPrefix"] }, { kind: "directive", type: i6.MatInput, selector: "input[matInput], textarea[matInput], select[matNativeControl],      input[matNativeControl], textarea[matNativeControl]", inputs: ["disabled", "id", "placeholder", "name", "required", "type", "errorStateMatcher", "aria-describedby", "value", "readonly"], exportAs: ["matInput"] }, { kind: "component", type: i7.MatTable, selector: "mat-table, table[mat-table]", exportAs: ["matTable"] }, { kind: "directive", type: i7.MatHeaderCellDef, selector: "[matHeaderCellDef]" }, { kind: "directive", type: i7.MatHeaderRowDef, selector: "[matHeaderRowDef]", inputs: ["matHeaderRowDef", "matHeaderRowDefSticky"] }, { kind: "directive", type: i7.MatColumnDef, selector: "[matColumnDef]", inputs: ["matColumnDef"] }, { kind: "directive", type: i7.MatCellDef, selector: "[matCellDef]" }, { kind: "directive", type: i7.MatRowDef, selector: "[matRowDef]", inputs: ["matRowDefColumns", "matRowDefWhen"] }, { kind: "directive", type: i7.MatHeaderCell, selector: "mat-header-cell, th[mat-header-cell]" }, { kind: "directive", type: i7.MatCell, selector: "mat-cell, td[mat-cell]" }, { kind: "component", type: i7.MatHeaderRow, selector: "mat-header-row, tr[mat-header-row]", exportAs: ["matHeaderRow"] }, { kind: "component", type: i7.MatRow, selector: "mat-row, tr[mat-row]", exportAs: ["matRow"] }, { kind: "directive", type: i7.MatNoDataRow, selector: "ng-template[matNoDataRow]" }, { kind: "directive", type: i8.MatSort, selector: "[matSort]", inputs: ["matSortActive", "matSortStart", "matSortDirection", "matSortDisableClear", "matSortDisabled"], outputs: ["matSortChange"], exportAs: ["matSort"] }, { kind: "component", type: i8.MatSortHeader, selector: "[mat-sort-header]", inputs: ["mat-sort-header", "arrowPosition", "start", "disabled", "sortActionDescription", "disableClear"], exportAs: ["matSortHeader"] }, { kind: "component", type: i9.MatPaginator, selector: "mat-paginator", inputs: ["color", "pageIndex", "length", "pageSize", "pageSizeOptions", "hidePageSize", "showFirstLastButtons", "selectConfig", "disabled"], outputs: ["page"], exportAs: ["matPaginator"] }, { kind: "directive", type: i10.MatTooltip, selector: "[matTooltip]", inputs: ["matTooltipPosition", "matTooltipPositionAtOrigin", "matTooltipDisabled", "matTooltipShowDelay", "matTooltipHideDelay", "matTooltipTouchGestures", "matTooltip", "matTooltipClass"], exportAs: ["matTooltip"] }, { kind: "component", type: i11.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { kind: "pipe", type: i1.DecimalPipe, name: "number" }, { kind: "pipe", type: i1.DatePipe, name: "date" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: TableComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-table', template: "<h3>{{title}}</h3>\r\n\r\n<mat-form-field appearance=\"outline\" *ngIf=\"showSearch\">\r\n    <mat-label>Search</mat-label>\r\n    <mat-icon matPrefix>search</mat-icon>\r\n    <input type=\"text\" matInput (keyup)=\"searchFilterChange($event)\">\r\n</mat-form-field>\r\n\r\n<div class=\"table-container\" [ngStyle]=\"{'max-height': maxTableHeight}\">\r\n    <table mat-table [dataSource]=\"dataSource\" matSort>\r\n      <ng-container *ngFor=\"let column of columns\" [matColumnDef]=\"column.field\">\r\n        <th mat-header-cell *matHeaderCellDef mat-sort-header [class.hide-mobile]=\"column.hideOnMobile && isMobile\" [ngStyle]=\"{ 'width': column.columnWidth }\">\r\n          <div>{{ column.fieldColumnTitle }}</div>\r\n        </th>\r\n\r\n        <td mat-cell *matCellDef=\"let data\" [class.hide-mobile]=\"column.hideOnMobile && isMobile\" [ngStyle]=\"{ 'width': column.columnWidth }\">\r\n          <span *ngIf=\"!column.isDate &&\r\n            !column.isPercent &&\r\n            !column.isNumber &&\r\n            !column.isCheckbox &&\r\n            !column.isButton &&\r\n            !column.isEditable &&\r\n            !column.nestedField &&\r\n            !column.isHyperlink\"\r\n          >\r\n            {{ data[column.field] }}\r\n          </span>\r\n\r\n          <span *ngIf=\"column.isHyperlink\">\r\n            <a [href]=\"data[column.isHyperlink.linkField]\" target=\"_blank\">\r\n              {{ data[column.field] }}\r\n            </a>\r\n          </span>\r\n\r\n          <span *ngIf=\"column.isDate\">\r\n            {{ data[column.field] | date:'shortDate' }}\r\n          </span>\r\n\r\n          <span *ngIf=\"column.isNumber && !column.isNumber.needsRounded && !column.isNumber.percentage\">\r\n            {{ data[column.field] | number:'.1-2' }}\r\n          </span>\r\n          <span *ngIf=\"column.isNumber && column.isNumber.needsRounded && !column.isNumber.percentage\">\r\n            {{ data[column.field] | number:'0.0-0' }}\r\n          </span>\r\n          <span *ngIf=\"column.isNumber && column.isNumber.needsRounded && column.isNumber.percentage\">\r\n            {{ data[column.field] | number:'0.0-0' }}%\r\n          </span>\r\n          <span *ngIf=\"column.isNumber && !column.isNumber.needsRounded && column.isNumber.percentage\">\r\n            {{ data[column.field] | number:'.1-2' }}%\r\n          </span>\r\n\r\n          <span *ngIf=\"column.isCheckbox\">\r\n            <mat-checkbox *ngIf=\"!column.isCheckbox['isDisabled']\"\r\n              [(ngModel)]=\"data[column.field]\">\r\n            </mat-checkbox>\r\n\r\n            <mat-checkbox *ngIf=\"column.isCheckbox['isDisabled']\"\r\n              [(ngModel)]=\"data[column.field]\"\r\n              disabled>\r\n            </mat-checkbox>\r\n          </span>\r\n\r\n          <span *ngIf=\"column.nestedField\">\r\n            {{ getNestedFieldValue(data[column.field], column.nestedField) }}\r\n          </span>\r\n\r\n          <span *ngIf=\"column.isButton\">\r\n            <button mat-icon-button *ngIf=\"column.isButton.isIcon && !column.isButton.isDisabled\"\r\n              [matTooltip]=\"column.isButton.isIcon.toolTip\"\r\n              (click)=\"buttonClick(data, column.field)\">\r\n              <mat-icon>{{column.isButton.isIcon.iconName}}</mat-icon>\r\n            </button>\r\n\r\n            <button mat-icon-button *ngIf=\"column.isButton.isIcon && column.isButton.isDisabled\" [matTooltip]=\"column.isButton.isIcon.toolTip\" disabled>\r\n              <mat-icon>{{column.isButton.isIcon.iconName}}</mat-icon>\r\n            </button>\r\n\r\n            <button mat-raised-button *ngIf=\"column.isButton && column.isButton.isDisabled && !column.isButton.isIcon && !column.isButton.isCheckbox\" disabled>\r\n              {{column.isButton.text}}\r\n            </button>\r\n\r\n            <button mat-raised-button color=\"primary\" *ngIf=\"column.isButton && !column.isButton.isDisabled && !column.isButton.isIcon && !column.isButton.isCheckbox\"\r\n              [ngClass]=\"{ 'button-extra-padding': column.isButton.extraPadding }\"\r\n              (click)=\"buttonClick(data, column.field)\">\r\n              {{column.isButton.text}}\r\n            </button>\r\n\r\n            <mat-checkbox *ngIf=\"column.isButton.isCheckbox\" [matTooltip]=\"column.isButton.isCheckbox.toolTip\"\r\n              [(ngModel)]=\"data[column.field]\" (click)=\"buttonClick(data, column.field)\">\r\n            </mat-checkbox>\r\n          </span>\r\n\r\n          <span *ngIf=\"column.isEditable\">\r\n            <textarea *ngIf=\"column.isEditable && column.isEditable.type === 'textarea'\" style=\"width: 100%;\" [rows]=\"3\" [(ngModel)]=\"data[column.field]\" [disabled]=\"column.isEditable.disable !== undefined && column.isEditable.disable\"></textarea>\r\n            <input *ngIf=\"column.isEditable && column.isEditable.type === 'input'\" [(ngModel)]=\"data[column.field]\" style=\"width: 55%;\"  [disabled]=\"column.isEditable.disable !== undefined && column.isEditable.disable\" [type]=\"column.isEditable.isNumber ? 'number' : 'text'\">\r\n          </span>\r\n        </td>\r\n      </ng-container>\r\n\r\n      <tr mat-header-row *matHeaderRowDef=\"columnNames; sticky: true\"></tr>\r\n      <tr mat-row *matRowDef=\"let row; columns: columnNames;\" class=\"table-row\" [ngClass]=\"{'shrink-table-row': shrinkTableRowHeight}\"></tr>\r\n      <tr mat-row *matNoDataRow>\r\n        <td class=\"mat-cell\" colspan=\"9999\">\r\n          No records exist.\r\n        </td>\r\n      </tr>\r\n    </table>\r\n    <mat-paginator *ngIf=\"showPaginator\" [ngClass]=\"{ 'paginator-sticky': paginatorSticky }\" [pageSizeOptions]=\"pageSizeOptions\" showFirstLastButtons></mat-paginator>\r\n</div>\r\n", styles: [".mat-form-field{width:100%!important}.table-container{display:grid;grid-template-columns:1fr;max-height:50em;overflow:auto;margin:1em .5em .5em;text-align:center!important}.table-container .table{width:100%}:host ::ng-deep .mat-sort-header-container{display:flex;justify-content:center}td,th{text-align:center!important}.shrink-table-row{height:.1em!important;min-height:.1em!important}.paginator-sticky{bottom:0;position:sticky;z-index:10}.button-extra-padding{padding-top:1.75em;padding-bottom:1.75em}\n"] }]
        }], ctorParameters: () => [], propDecorators: { title: [{
                type: Input
            }], tableData: [{
                type: Input
            }], columns: [{
                type: Input
            }], showPaginator: [{
                type: Input
            }], showSearch: [{
                type: Input
            }], maxTableHeight: [{
                type: Input
            }], shrinkTableRowHeight: [{
                type: Input
            }], paginatorSticky: [{
                type: Input
            }], buttonClicked: [{
                type: Output
            }], matSort: [{
                type: ViewChild,
                args: [MatSort]
            }], matPaginator: [{
                type: ViewChild,
                args: [MatPaginator]
            }] } });

class TableModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: TableModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.3.0", ngImport: i0, type: TableModule, declarations: [TableComponent], imports: [CommonModule,
            FormsModule,
            ReactiveFormsModule,
            MatButtonModule,
            MatCheckboxModule,
            MatFormFieldModule,
            MatInputModule,
            MatTableModule,
            MatSortModule,
            MatPaginatorModule,
            MatTooltipModule,
            MatIconModule], exports: [TableComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: TableModule, imports: [CommonModule,
            FormsModule,
            ReactiveFormsModule,
            MatButtonModule,
            MatCheckboxModule,
            MatFormFieldModule,
            MatInputModule,
            MatTableModule,
            MatSortModule,
            MatPaginatorModule,
            MatTooltipModule,
            MatIconModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: TableModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        TableComponent
                    ],
                    imports: [
                        CommonModule,
                        FormsModule,
                        ReactiveFormsModule,
                        MatButtonModule,
                        MatCheckboxModule,
                        MatFormFieldModule,
                        MatInputModule,
                        MatTableModule,
                        MatSortModule,
                        MatPaginatorModule,
                        MatTooltipModule,
                        MatIconModule
                    ],
                    exports: [
                        TableComponent
                    ]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { TableComponent, TableModule };
//# sourceMappingURL=cleavelandprice-ngx-lib-table.mjs.map
